@@ -34,23 +34,7 @@ FilterInformationGain = R6Class("FilterInformationGain",
   public = list(
 
     #' @description Create a FilterInformationGain object.
-    #' @param id (`character(1)`)\cr
-    #'   Identifier for the filter.
-    #' @param task_type (`character()`)\cr
-    #'   Types of the task the filter can operator on. E.g., `"classif"` or
-    #'   `"regr"`.
-    #' @param param_set ([paradox::ParamSet])\cr
-    #'   Set of hyperparameters.
-    #' @param feature_types (`character()`)\cr
-    #'   Feature types the filter operates on.
-    #'   Must be a subset of
-    #'   [`mlr_reflections$task_feature_types`][mlr3::mlr_reflections].
-    #' @param packages (`character()`)\cr
-    #'   Set of required packages.
-    #'   Note that these packages will be loaded via [requireNamespace()], and
-    #'   are not attached.
-    initialize = function(id = "information_gain",
-      task_type = c("classif", "regr"),
+    initialize = function() {
       param_set = ParamSet$new(list(
         ParamFct$new("type",
           levels = c("infogain", "gainratio", "symuncert"),
@@ -58,15 +42,14 @@ FilterInformationGain = R6Class("FilterInformationGain",
         ParamLgl$new("equal", default = FALSE),
         ParamLgl$new("discIntegers", default = TRUE),
         ParamInt$new("threads", lower = 0L, default = 1L)
-      )),
-      packages = "FSelectorRcpp",
-      feature_types = c("integer", "numeric", "factor", "ordered")) {
+      ))
+
       super$initialize(
-        id = id,
-        task_type = task_type,
+        id = "information_gain",
+        task_type = c("classif", "regr"),
         param_set = param_set,
-        feature_types = feature_types,
-        packages = packages,
+        feature_types = c("integer", "numeric", "factor", "ordered"),
+        packages = "FSelectorRcpp",
         man = "mlr3filters::mlr_filters_information_gain"
       )
     }
