@@ -7,6 +7,7 @@
 #'
 #' This filter supports partial scoring (see [Filter]).
 #'
+#' @template details_praznik
 #' @family Filter
 #' @template seealso_filter
 #' @export
@@ -21,34 +22,16 @@ FilterNJMIM = R6Class("FilterNJMIM",
   public = list(
 
     #' @description Create a FilterNJMIM object.
-    #' @param id (`character(1)`)\cr
-    #'   Identifier for the filter.
-    #' @param task_type (`character()`)\cr
-    #'   Types of the task the filter can operator on. E.g., `"classif"` or
-    #'   `"regr"`.
-    #' @param param_set ([paradox::ParamSet])\cr
-    #'   Set of hyperparameters.
-    #' @param feature_types (`character()`)\cr
-    #'   Feature types the filter operates on.
-    #'   Must be a subset of
-    #'   [`mlr_reflections$task_feature_types`][mlr3::mlr_reflections].
-    #' @param packages (`character()`)\cr
-    #'   Set of required packages.
-    #'   Note that these packages will be loaded via [requireNamespace()], and
-    #'   are not attached.
-    initialize = function(id = "njmim",
-      task_type = "classif",
+    initialize = function() {
       param_set = ParamSet$new(list(
         ParamInt$new("threads", lower = 0L, default = 0L)
-      )),
-      packages = "praznik",
-      feature_types = c("integer", "numeric", "factor", "ordered")) {
+      ))
       super$initialize(
-        id = id,
-        task_type = task_type,
+        id = "njmim",
+        task_type = "classif",
         param_set = param_set,
-        feature_types = feature_types,
-        packages = packages,
+        packages = "praznik",
+        feature_types = c("integer", "numeric", "factor", "ordered"),
         man = "mlr3filters::mlr_filters_njmim"
       )
     }
@@ -59,7 +42,7 @@ FilterNJMIM = R6Class("FilterNJMIM",
       threads = self$param_set$values$threads %??% 0L
       X = task$data(cols = task$feature_names)
       Y = task$truth()
-      praznik::NJMIM(X = X, Y = Y, k = nfeat, threads = threads)$score
+      reencode_praznik_score(praznik::NJMIM(X = X, Y = Y, k = nfeat, threads = threads))
     }
   )
 )
