@@ -33,43 +33,31 @@ FilterPermutation = R6Class("FilterPermutation",
     measure = NULL,
 
     #' @description Create a FilterDISR object.
-    #' @param id (`character(1)`)\cr
-    #'   Identifier for the filter.
-    #' @param task_type (`character()`)\cr
-    #'   Types of the task the filter can operator on. E.g., `"classif"` or
-    #'   `"regr"`.
-    #' @param param_set ([paradox::ParamSet])\cr
-    #'   Set of hyperparameters.
-    #' @param feature_types (`character()`)\cr
-    #'   Feature types the filter operates on.
-    #'   Must be a subset of
-    #'   [`mlr_reflections$task_feature_types`][mlr3::mlr_reflections].
     #' @param learner ([mlr3::Learner])\cr
     #'   [mlr3::Learner] to use for model fitting.
     #' @param resampling ([mlr3::Resampling])\cr
     #'   [mlr3::Resampling] to be used within resampling.
     #' @param measure ([mlr3::Measure])\cr
     #'   [mlr3::Measure] to be used for evaluating the performance.
-    initialize = function(id = "permutation",
-      task_type = learner$task_type,
+    initialize = function(learner = mlr3::lrn("classif.rpart"), resampling = mlr3::rsmp("holdout"),
+      measure = NULL) {
+
+
       param_set = ParamSet$new(list(
         ParamLgl$new("standardize", default = FALSE),
-        ParamInt$new("nmc", default = 50L))),
-      feature_types = learner$feature_types,
-      learner = mlr3::lrn("classif.rpart"),
-      resampling = mlr3::rsmp("holdout"),
-      measure = mlr3::msr("classif.ce")) {
+        ParamInt$new("nmc", lower = 1L, default = 50L))
+      )
 
       self$learner = learner = assert_learner(as_learner(learner, clone = TRUE))
-      self$resampling = assert_resampling(as_resampling(resampling))
+      self$resampling = assert_resampling(as_resampling(resampling), instantiated = FALSE)
       self$measure = assert_measure(as_measure(measure,
         task_type = learner$task_type, clone = TRUE), learner = learner)
       packages = unique(c(self$learner$packages, self$measure$packages))
 
       super$initialize(
-        id = id,
-        task_type = task_type,
-        feature_types = feature_types,
+        id = "permutation",
+        task_type = learner$task_type,
+        feature_types = learner$feature_types,
         packages = packages,
         param_set = param_set,
         man = "mlr3filters::mlr_filters_performance"
@@ -79,41 +67,45 @@ FilterPermutation = R6Class("FilterPermutation",
 
   private = list(
     .calculate = function(task, nfeat) {
-
       task = task$clone()
-      pars = self$param_set$values
       fn = task$feature_names
-      pars$standardize = pars$standardize %??% FALSE
-      pars$nmc = pars$nmc %??% 50L
+      nmc = self$param_set$values$nmc %??% 50L
 
+      backend = task$backend
       rr = resample(task, self$learner, self$resampling)
       baseline = rr$aggregate(self$measure)
 
-      perf = map_dtr(seq(pars$nmc), function(i) {
-        set_names(map_dtc(fn, function(x) {
+      perf = matrix(NA_real_, nrow = nmc, ncol = length(fn),
+        dimnames = list(NULL, fn))
 
-          task = task$clone()
-          data = task$data()
-          column = task$data(cols = x)
-          data[, (x) := column[sample(nrow(data))]]
+      for (j in seq_col(perf)) {
+        data = task$data(cols = fn[j])
 
-          # Empty task and fill with shuffled column
-          task$filter(rows = 0)
-          task$rbind(data)
+        for (i in seq_row(perf)) {
+          data[[1L]] = shuffle(data[[1L]])
+          task$cbind(data)
           rr = resample(task, self$learner, self$resampling)
-          rr$aggregate(self$measure)
-        }), fn)
-      })
-      delta = baseline - as.matrix(perf[, lapply(.SD, mean)])[1, ]
+          perf[i, j] = rr$aggregate(self$measure)
+
+          # reset to previous backend
+          # this is a bit of an ugly hack, but since we are only overwriting
+          # a column with its own values during `task$cbind()`, this should pose
+          # no problem.
+          task$backend = backend
+        }
+      }
+
+      delta = baseline - colMeans(perf)
 
       if (self$measure$minimize) {
         delta = -delta
       }
 
-      if (pars$standardize) {
+      if (!isTRUE(self$param_set$values$standardize)) {
         delta = delta / max(delta)
       }
-      set_names(delta, fn)
+
+      delta
     }
   )
 )
